/* $Author: karu $ */
/* $Modified by Guangyu Shi $*/
/* $LastChangedDate: 2010-11-7 $ */
/* $Rev: 46 $ */
// Synthesizable memory

//////////////////////////////////////
//
// Memory -- single cycle version
//
// written for CS/ECE 552, Spring '07
// Pratap Ramamurthy, 19 Mar 2006
//
// This is a word-addressable,
// 16-bit wide memory
//
// All reads happen combinationally with zero delay.
// All writes occur on rising clock edge.
// Concurrent read and write not allowed.
//
// On reset, memory loads from file "loadfile_all.img".
// (You may change the name of the file in
// the $readmemh statement below.)
// File format:
//     @0
//     <hex data 0>
//     <hex data 1>
//     ...etc
//
// If input "createdump" is true on rising clock,
// contents of memory will be dumped to
// file "dumpfile", from location 0 up through
// the highest location modified by a write.
//
//
//////////////////////////////////////

module memory1c (data_out, data_in, addr, enable, wr, clk);
   parameter DATA_WIDTH = 16;
   output  [DATA_WIDTH-1:0] data_out;
   input [DATA_WIDTH-1:0]   data_in;
   input [5:0]   addr;
   input          enable;
   input          wr;
   input          clk;

   wire [DATA_WIDTH-1:0]    data_out;
   
   reg [DATA_WIDTH-1:0]      mem [0:63];
   reg            loaded;

   assign         data_out = (enable & (~wr))? { mem[addr]  }:0;
   initial begin
      loaded = 0;
   end

   always @(posedge clk) begin
         if (enable & wr) begin
	        mem[addr] = data_in[DATA_WIDTH-1:0];       // The actual write
         end
   end

endmodule  // memory1c
// DUMMY LINE FOR REV CONTROL :0:


